"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = MathEditorButtons;
const jsx_runtime_1 = require("react/jsx-runtime");
const styled_components_1 = __importDefault(require("styled-components"));
const math_shortcut_data_1 = __importDefault(require("../math-shortcut-data"));
const state_1 = __importDefault(require("../../../state"));
const utility_1 = require("../../../utility");
const undo_1 = __importDefault(require("../../icons/undo"));
const redo_1 = __importDefault(require("../../icons/redo"));
function MathEditorButtons() {
    const { isMathToolbarOpen, undoEquation, redoEquation, canUndoEquation, canRedoEquation, activeMathEditor } = (0, state_1.default)();
    function onMouseDown(e, shortcut) {
        var _a;
        e.preventDefault();
        e.stopPropagation();
        if (activeMathEditor === null || activeMathEditor === void 0 ? void 0 : activeMathEditor.mq.el().contains(document.activeElement)) {
            /** Different inputs need to be given to MathQuill differently.
             * Something about inputting a 'LaTeX command' rather than straight text.
             */
            activeMathEditor.mq[(_a = shortcut.fn) !== null && _a !== void 0 ? _a : 'cmd'](shortcut.action);
        }
        else {
            window.document.execCommand('insertText', false, shortcut.label);
        }
    }
    const onHistoryEvent = (fn) => (0, utility_1.eventHandlerWithoutFocusLoss)(() => {
        const newValue = fn();
        if (newValue !== undefined) {
            activeMathEditor === null || activeMathEditor === void 0 ? void 0 : activeMathEditor.setLatex(newValue);
        }
    });
    return isMathToolbarOpen ? ((0, jsx_runtime_1.jsxs)(Container, { "data-testid": "math-toolbar", children: [(0, jsx_runtime_1.jsx)(Grid, { children: math_shortcut_data_1.default.map((shortcut, i) => ((0, jsx_runtime_1.jsx)(LatexCommandButton, { onMouseDown: (e) => onMouseDown(e, shortcut), "data-testid": `math-command-${shortcut.action}`, children: (0, jsx_runtime_1.jsx)("img", { src: shortcut.svg }) }, `math-shortcut-${i}`))) }), (0, jsx_runtime_1.jsxs)(ButtonContainer, { children: [(0, jsx_runtime_1.jsx)(HistoryButton, { onMouseDown: onHistoryEvent(undoEquation), disabled: !canUndoEquation, "data-testid": "undo", children: (0, jsx_runtime_1.jsx)(undo_1.default, {}) }), (0, jsx_runtime_1.jsx)(HistoryButton, { onMouseDown: onHistoryEvent(redoEquation), disabled: !canRedoEquation, "data-testid": "redo", children: (0, jsx_runtime_1.jsx)(redo_1.default, {}) })] })] })) : null;
}
const buttonWidth = '35px';
const Container = styled_components_1.default.div `
  display: contents;
  position: absolute;
  top: 100%;
  width: 100%;
  background-color: #fafafa;

  &::before {
    content: '';
    grid-row: 2 / 3;
    z-index: 10;
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    pointer-events: none; /* Prevent interference with grid items */
    background: #fafafa;
    border-top: 1px solid #dfdfdf;
  }
`;
const Grid = styled_components_1.default.div `
  grid-column: 2;
  grid-row: 2;
  display: grid;
  grid-template-columns: repeat(17, 1fr);
  grid-template-rows: 1fr 1fr;
  width: fit-content;

  @media (max-width: 799px) {
    grid-column: 1;
  }
`;
const Button = styled_components_1.default.button `
  width: ${buttonWidth};
  height: ${buttonWidth};
  z-index: 11;

  & > img {
    max-width: ${buttonWidth};
    max-height: ${buttonWidth};
  }

  background: none;
  border: none;

  cursor: pointer;
  padding: 0;
`;
const LatexCommandButton = (0, styled_components_1.default)(Button) `
  font-family: Symbola, monospace;
  font-size: 16px;
  color: #555;

  transition: background-color 75ms;

  &:hover {
    background-color: #f0f0f0;
  }
  &:active {
    background-color: #e0e0e0;
  }
`;
const HistoryButton = (0, styled_components_1.default)(Button) `
  &:disabled {
    opacity: 50%;
    filter: grayscale(1);
    pointer-events: none;
    cursor: default;
  }
`;
const ButtonContainer = styled_components_1.default.div `
  display: flex;

  z-index: 11;
  grid-column: 3;
  grid-row: 2;

  @media (max-width: 799px) {
    position: absolute;
    right: 0;
  }
`;
