"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sanitize = sanitize;
exports.sanitizeText = sanitizeText;
const sanitize_html_1 = __importDefault(require("sanitize-html"));
const sanitizeOpts = {
    allowedTags: ['img', 'br', 'span'],
    allowedAttributes: {
        img: ['src', 'alt'],
    },
    allowedSchemes: ['data'],
};
function sanitize(html, opts) {
    let isInsideHeadTag = false;
    return [
        (v) => (0, sanitize_html_1.default)(v, Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, sanitizeOpts), { allowedTags: [...sanitizeOpts.allowedTags, 'div', 'p'], allowedSchemes: ['data', 'http', 'https'] }), opts), { 
            // We need to track if we are inside a head tag, because we don't want to add <br>s inside head tags
            onOpenTag: (tag) => (tag === 'head' ? (isInsideHeadTag = true) : undefined), onCloseTag: (tag) => (tag === 'head' ? (isInsideHeadTag = false) : undefined), textFilter: (text) => {
                if (isInsideHeadTag) {
                    return text;
                }
                if (text === '\n') {
                    return '';
                }
                return text.replaceAll(/\n/g, '<br>');
            } }), opts)),
        (v) => convertLinksToRelative(v),
        (v) => stripBlockElements(v),
        (v) => preserveIndentation(v),
        (v) => preserveTabs(v),
    ].reduce((value, fn) => fn(value), html);
}
function convertLinksToRelative(html) {
    return html.replace(new RegExp(document.location.origin, 'g'), '');
}
function isBlockElement(node) {
    return node.nodeName === 'DIV' || node.nodeName === 'P';
}
// This is copied pretty much as-is from the legacy jQuery version;
// it's difficult to say *what exactly* it does but it attempts to
// change block-elements (namely `div` and `p`) into `br`s.
function stripBlockElements(html) {
    var _a;
    const parent = document.createElement('div');
    parent.innerHTML = html.trim();
    do {
        let lastNode = undefined;
        for (let i = 0; i < parent.childNodes.length; i++) {
            const node = parent.childNodes[i];
            if (isBlockElement(node)) {
                // if the last node is a text node or a span, which is not empty, add a br before this node
                if (lastNode !== undefined &&
                    (lastNode.nodeType === Node.TEXT_NODE || lastNode.nodeName === 'SPAN') &&
                    /\S/.test((_a = lastNode.textContent) !== null && _a !== void 0 ? _a : '')) {
                    parent.insertBefore(document.createElement('br'), node);
                }
                // if this node has a last child that is not a br, add a br
                if (node.lastChild && node.lastChild.nodeName !== 'BR') {
                    node.insertBefore(document.createElement('br'), null);
                }
                while (node.childNodes.length && node.firstChild !== null) {
                    parent.insertBefore(node.firstChild, node);
                }
                parent.removeChild(node);
            }
            lastNode = node;
        }
    } while (Array.prototype.some.call(parent.childNodes, (node) => isBlockElement(node)));
    return parent.innerHTML;
}
function preserveTabs(html) {
    return html.replace(/\t/g, '&nbsp;&nbsp;&nbsp;&nbsp;');
}
function sanitizeText(text) {
    return [escapeHtml, preserveLineBreaks, preserveIndentation].reduce((value, fn) => fn(value), text);
}
function preserveIndentation(html) {
    const parent = document.createElement('div');
    parent.innerHTML = html;
    Array.from(parent.childNodes).forEach((node) => {
        var _a, _b, _c, _d;
        if (node.textContent) {
            const nodeIsPrecededByBR = ((_a = node.previousSibling) === null || _a === void 0 ? void 0 : _a.nodeName) === 'BR';
            if (nodeIsPrecededByBR) {
                const spaces = (_c = (_b = node.textContent) === null || _b === void 0 ? void 0 : _b.match(/^(\s+)/)) === null || _c === void 0 ? void 0 : _c[0];
                if (spaces) {
                    node.textContent = (_d = node.textContent) === null || _d === void 0 ? void 0 : _d.replace(spaces, spaces.replaceAll(' ', '\u00A0'));
                }
            }
        }
    });
    return parent.innerHTML;
}
function preserveLineBreaks(text) {
    return text.replaceAll(/\n/g, '<br>');
}
function escapeHtml(text) {
    return String(text)
        .replaceAll('&', '&amp;')
        .replaceAll('<', '&lt;')
        .replaceAll('>', '&gt;')
        .replaceAll('"', '&quot;')
        .replaceAll("'", '&#39;');
}
